==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-core/src/main/java/org/apache/maven/lifecycle/mapping/LifecycleMojo.java <==
package org.apache.maven.lifecycle.mapping;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.List;

import org.apache.maven.model.Dependency;
import org.codehaus.plexus.util.xml.Xpp3Dom;

/**
 * LifecycleMojo
 */
public class LifecycleMojo
{
    
    private String goal;
    private Xpp3Dom configuration;
    private List<Dependency> dependencies;
    
    public String getGoal()
    {
        return goal;
    }
    
    public Xpp3Dom getConfiguration()
    {
        return configuration;
    }
    
    public List<Dependency> getDependencies()
    {
        return dependencies;
    }
    
    public void setGoal( String goal )
    {
        this.goal = goal;
    }
    
    public void setConfiguration( Xpp3Dom configuration )
    {
        this.configuration = configuration;
    }
    
    public void setDependencies( List<Dependency> dependencies )
    {
        this.dependencies = dependencies;
    }
}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-core/src/main/java/org/apache/maven/lifecycle/mapping/LifecycleMojo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.lifecycle.mapping;

import java.util.List;

import org.apache.maven.model.Dependency;
import org.codehaus.plexus.util.xml.Xpp3Dom;

/**
 * LifecycleMojo
 */
public class LifecycleMojo {

    private String goal;
    private Xpp3Dom configuration;
    private List<Dependency> dependencies;

    public String getGoal() {
        return goal;
    }

    public Xpp3Dom getConfiguration() {
        return configuration;
    }

    public List<Dependency> getDependencies() {
        return dependencies;
    }

    public void setGoal(String goal) {
        this.goal = goal;
    }

    public void setConfiguration(Xpp3Dom configuration) {
        this.configuration = configuration;
    }

    public void setDependencies(List<Dependency> dependencies) {
        this.dependencies = dependencies;
    }
}
